@@ -117,12 +117,12 @@ struct Config {
 ///
 fn main() -> Result<(), Box<dyn std::error::Error>> {
     let prism_dir = format!("prism-{}", env!("CARGO_PKG_VERSION"));
-    let config_path = Path::new(env!("CARGO_MANIFEST_DIR")).join("vendor").join(prism_dir).join("config.yml");
+    let config_path = Path::new(env!("CARGO_MANIFEST_DIR")).join("vendor").join(prism_dir).join("config.json");
 
     let config_file = std::fs::File::open(&config_path)?;
     println!("cargo:rerun-if-changed={}", config_path.to_str().unwrap());
 
-    let config: Config = serde_yaml::from_reader(config_file)?;
+    let config: Config = serde_json::from_reader(config_file)?;
     write_bindings(&config)?;
 
     Ok(())
@@ -142,10 +142,10 @@ fn struct_name(name: &str) -> String {
     result
 }
 
-fn kind_to_type(kind: &String) -> String {
-    match kind.as_str() {
+fn kind_to_type(kind: &str) -> String {
+    match kind {
         "non-void expression" | "pattern expression" | "Node" => String::new(),
-        _ => kind.to_string(),
+        _ => kind.to_owned(),
     }
 }
 
